@@ -3,7 +3,7 @@ BEGIN {
   $IO::WrapOutput::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $IO::WrapOutput::VERSION = '0.05';
+  $IO::WrapOutput::VERSION = '0.06';
 }
 
 use strict;
@@ -20,6 +20,8 @@ our %EXPORT_TAGS = (ALL => [@EXPORT]);
 my ($orig_stderr, $orig_stdout);
 
 sub wrap_output {
+    # 2-arg open() here because Perl 5.6 doesn't understand the '>&' mode
+    # with a 3-arg open
     open $orig_stdout, '>&'.fileno(STDOUT) or croak("Can't dup STDOUT: $!");
     open $orig_stderr, '>&'.fileno(STDERR) or croak("Can't dup STDERR: $!");
 
@@ -126,14 +128,15 @@ IO::WrapOutput - Wrap your output filehandles with minimal fuss
 
 =head1 DESCRIPTION
 
-When you have a module which needs all output to go through a method that it
-provides (e.g. ReadLine), it can be cumbersome (or even impossible) to
-change all the code in your program to do that instead of printing to
-STDOUT/STDERR. That's where C<IO::WrapOutput> comes in.
+When you have a module (e.g. POE::Wheel::ReadLine) which needs all output
+to go through a method that it provides, it can be cumbersome (or even
+impossible) to change all the code in an asynchronous/event-driven program
+to do that instead of printing directly to STDOUT/STDERR. That's
+where C<IO::WrapOutput> comes in.
 
 You just do the setup work for the output-hogging module in question, then
-call C<wrap_output> which will return filehands that you can read from. Then
-you take what you get from those filehandles and feed it into your
+call C<wrap_output> which will return filehandles that you can read from.
+Then you take what you get from those filehandles and feed it into your
 output-hogging module's output method. After you stop using the
 output-hogging module, you can restore your original STDOUT/STDERR handles
 with C<unwrap_output>.
